**********
References
**********

.. [tolerances] `Optimality conditions and numerical tolerances in QP solvers <https://scaron.info/blog/optimality-conditions-and-numerical-tolerances-in-qp-solvers.html>`_, S. Caron, 2022.

.. [Bambade2022] `PROX-QP: Yet another Quadratic Programming Solver for Robotics and beyond <https://hal.inria.fr/hal-03683733/file/Yet_another_QP_solver_for_robotics_and_beyond.pdf/>`__, A. Bambade, S. El-Kazdadi, A. Taylor and J. Carpentier. Robotics: Science and Systems. 2022.

.. [ODonoghue2021] `Operator splitting for a homogeneous embedding of the linear complementarity problem <https://arxiv.org/abs/2004.02177>`_, B. O'Donoghue. SIAM Journal on Optimization, 2021, vol. 31, no 3, p. 1999-2023.

.. [Frison2020] `HPIPM: a high-performance quadratic programming framework for model predictive control <https://arxiv.org/abs/2003.02547>`__, G. Frison and M. Diehl. IFAC-PapersOnline, 2020, vol. 53, no 2, p. 6563-6569.

.. [Stellato2020] `OSQP: An Operator Splitting Solver for Quadratic Programs <https://arxiv.org/abs/1711.08013>`__, B. Stellato, G. Banjac, P. Goulart, A. Bemporad, and S. Boyd. Mathematical Programming Computation, 2020, vol. 12, no 4, p. 637-672.

.. [Pandala2019] `qpSWIFT: A real-time sparse quadratic program solver for robotic applications <https://doi.org/10.1109/LRA.2019.2926664>`_, A. G. Pandala, Y. Ding and H. W. Park. IEEE Robotics and Automation Letters, 2019, vol. 4, no 4, p. 3355-3362.

.. [Huangfu2018] *Parallelizing the dual revised simplex method*. Q. Huangfu and J. Hall. Mathematical Programming Computation, 2018, vol. 10, no 1, p. 119-142.

.. [Ferreau2014] `qpOASES: A parametric active-set algorithm for quadratic programming <http://mpc.zib.de/archive/2014/4/Ferreau2014_Article_QpOASESAParametricActive-setAl.pdf>`_, H. J. Ferreau, C. Kirches, A. Potschka, H. G. Bock and M. Diehl. Mathematical Programming Computation, 2014, vol. 6, no 4, p. 327-363.

.. [Domahidi2013] `ECOS: An SOCP solver for embedded systems <https://web.stanford.edu/~boyd/papers/ecos.html>`_, A. Domahidi, E. Chu and S. Boyd. European Control Conference. IEEE, 2013. p. 3071-3076.

.. [Vandenberghe2010] `The CVXOPT linear and quadratic cone program solvers <https://www.seas.ucla.edu/~vandenbe/publications/coneprog.pdf>`_, L. Vandenberghe. 2010.

.. [Goldfarb1983] *A numerically stable dual method for solving strictly convex quadratic programs*. D. Goldfarb and A. Idnani. Mathematical Programming, vol. 27, p. 1-33.

.. [Arnstrom2022] `A dual active-set solver for embedded quadratic programming using recursive LDL updates <https://doi.org/10.1109/TAC.2022.3176430>`_, D. Arnström, A. Bemporad and D. Axehill. IEEE Transactions on Automatic Control, 2022, 67, no. 8 p. 4362-4369.

.. [schwan2023piqp] `PIQP: A Proximal Interior-Point Quadratic Programming Solver <https://arxiv.org/abs/2304.00290>`_, R. Schwan, Y. Jiang, D. Kuhn, C.N. Jones. ArXiv, 2023.
